@@ -51,30 +51,36 @@ class BaseApp():
         self.app.register_blueprint(bp)
 
     def _add_admin_views(self):
-        self.add_view_no_menu(self.indexview)
-        self.add_view_no_menu(LocaleView)
-        self.add_view_no_menu(AuthView)
-        self.add_view_no_menu(ResetPasswordView)
-        self.add_view_no_menu(ResetMyPasswordView)
+        self.add_view_no_menu(self.indexview())
+        self.add_view_no_menu(LocaleView())
+        self.add_view_no_menu(AuthView())
+        self.add_view_no_menu(ResetPasswordView())
+        self.add_view_no_menu(ResetMyPasswordView())
 
-        self.add_view(UserGeneralView, "List Users"
+        self.add_view(UserGeneralView(), "List Users"
                                         ,"/users/list","user",
                                         "Security")
-        self.add_view(RoleGeneralView, "List Roles","/roles/list","tags","Security")
+        self.add_view(RoleGeneralView(), "List Roles","/roles/list","tags","Security")
         self.menu.add_separator("Security")
-        self.add_view(PermissionViewGeneralView, "Base Permissions","/permissions/list","lock","Security")
-        self.add_view(ViewMenuGeneralView, "Views/Menus","/viewmenus/list","list-alt","Security")
-        self.add_view(PermissionGeneralView, "Permission on Views/Menus","/permissionviews/list","lock","Security")
+        self.add_view(PermissionViewGeneralView(), "Base Permissions","/permissions/list","lock","Security")
+        self.add_view(ViewMenuGeneralView(), "Views/Menus","/viewmenus/list","list-alt","Security")
+        self.add_view(PermissionGeneralView(), "Permission on Views/Menus","/permissionviews/list","lock","Security")
 
         
-    def add_view(self, baseview, name, href, icon, category):
-        print "Registering:", category,".", name, "at", href
-        self.menu.add_link(name, href, icon, category)
+    def add_view(self, baseview, name, href = "", icon = "", category = ""):
+        print "Registering:", category,".", name
         if baseview not in self.lst_baseview:
             baseview.baseapp = self
             self.lst_baseview.append(baseview)
             self.register_blueprint(baseview)
             self._add_permission(baseview)
+	self.menu.add_link(name = name, href = href, icon = icon, parent_category = category, baseview = baseview)
+        
+    def add_link(self, name, href, icon = "", category = ""):
+    	self.menu.add_link(name = name, href = href, icon = icon, parent_category = category)
+
+    def add_separator(self, category):
+        self.menu.add_separator(category)
 
     def add_view_no_menu(self, baseview, endpoint = None, static_folder = None):
         if baseview not in self.lst_baseview:
@@ -85,7 +91,7 @@ class BaseApp():
 
     def _add_permission(self, baseview):
         pvm = PermissionView()
-        bv = baseview()
+        bv = baseview
         try:
             pvm.add_view_permissions(bv.base_permissions, bv.__class__.__name__)
         except:
@@ -94,4 +100,4 @@ class BaseApp():
         pvm = None
 
     def register_blueprint(self, baseview, endpoint = None, static_folder = None):
-        self.app.register_blueprint(baseview().create_blueprint(self,  endpoint = endpoint, static_folder = static_folder))
+        self.app.register_blueprint(baseview.create_blueprint(self,  endpoint = endpoint, static_folder = static_folder))
